@@ -1,11 +1,7 @@
-# Licensed to Elasticsearch B.V under one or more agreements.
-# Elasticsearch B.V licenses this file to you under the Apache 2.0 License.
-# See the LICENSE file in the project root for more information
+package Search::Elasticsearch::Client::2_0;
 
-package Search::Elasticsearch::Client::1_0;
-
-our $VERSION='7.30_1';
-use Search::Elasticsearch 7.00 ();
+our $VERSION='5.00';
+use Search::Elasticsearch 5.00 ();
 
 1;
 
@@ -15,11 +11,11 @@ use Search::Elasticsearch 7.00 ();
 
 =head1 NAME
 
-Search::Elasticsearch::Client::1_0 - Thin client with full support for Elasticsearch 1.x APIs
+Search::Elasticsearch::Client::2_0 - Thin client with full support for Elasticsearch 1.x APIs
 
 =head1 VERSION
 
-version 7.30_1
+version 5.00
 
 =head1 DESCRIPTION
 
@@ -31,16 +27,16 @@ with L<Search::Elasticsearch> as follows:
         client => "1_0::Direct"
     );
 
-See L<Search::Elasticsearch::Client::1_0::Direct> for documentation
+See C<Search::Elasticsearch::Client::1_0::Direct> for documentation
 about how to use the client itself.
 
 =head1 AUTHOR
 
-Enrico Zimuel <enrico.zimuel@elastic.co>
+Clinton Gormley <drtech@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2020 by Elasticsearch BV.
+This software is Copyright (c) 2016 by Elasticsearch BV.
 
 This is free software, licensed under:
 
