@@ -1,15 +1,11 @@
-# Licensed to Elasticsearch B.V under one or more agreements.
-# Elasticsearch B.V licenses this file to you under the Apache 2.0 License.
-# See the LICENSE file in the project root for more information
-
-package Search::Elasticsearch::Client::1_0::Direct;
+package Search::Elasticsearch::Client::2_0::Direct;
 
 use Moo;
-with 'Search::Elasticsearch::Client::1_0::Role::API';
+with 'Search::Elasticsearch::Client::2_0::Role::API';
 with 'Search::Elasticsearch::Role::Client::Direct';
 
-our $VERSION='7.30_1';
-use Search::Elasticsearch 7.00 ();
+our $VERSION='5.00';
+use Search::Elasticsearch 5.00 ();
 
 use Search::Elasticsearch::Util qw(parse_params is_compat);
 use namespace::clean;
@@ -89,11 +85,11 @@ __PACKAGE__->_install_api('');
 
 =head1 NAME
 
-Search::Elasticsearch::Client::1_0::Direct - Thin client with full support for Elasticsearch 1.x APIs
+Search::Elasticsearch::Client::2_0::Direct - Thin client with full support for Elasticsearch 2.x APIs
 
 =head1 VERSION
 
-version 7.30_1
+version 5.00
 
 =head1 SYNOPSIS
 
@@ -101,7 +97,7 @@ Create a client:
 
     use Search::Elasticsearch;
     my $e = Search::Elasticsearch->new(
-        client => '1_0::Direct'
+        client => '2_0::Direct'
     );
 
 Index a doc:
@@ -167,6 +163,10 @@ Snapshot and restore:
         snapshot   => 'backup_2014'
     );
 
+Task management:
+
+    $e->tasks->list;
+
 `cat` debugging:
 
     say $e->cat->allocation;
@@ -174,10 +174,12 @@ Snapshot and restore:
 
 =head1 DESCRIPTION
 
-The L<Search::Elasticsearch::Client::1_0::Direct> class provides the
-Elasticsearch 1.x compatible client that is returned by:
+The L<Search::Elasticsearch::Client::2_0::Direct> class provides the
+Elasticsearch 2.x compatible client returned by:
 
-    $e = Search::Elasticsearch->new( cxn => '1_0::Direct' );
+    $e = Search::Elasticsearch->new(
+        client => "2_0::Direct"
+    );
 
 It is intended to be as close as possible to the native REST API that
 Elasticsearch uses, so that it is easy to translate the
@@ -251,11 +253,9 @@ you can do:
 
     $e->search(
         query => {...},
-        filter_path => [ 'hits.total', 'hits.hits._source' ]
+        filter_paths => [ 'hits.total', 'hits.hits._source' ]
     );
 
-This parameter was added in Elasticsearch 1.6.0.
-
 =head2 Ignore parameter
 
 Normally, any HTTP status code outside the 200-299 range will result in
@@ -284,12 +284,12 @@ Multiple error codes can be specified with an array:
 =head2 C<bulk_helper_class>
 
 The class to use for the L</bulk_helper()> method. Defaults to
-L<Search::Elasticsearch::Client::1_0::Bulk>.
+L<Search::Elasticsearch::Client::2_0::Bulk>.
 
 =head2 C<scroll_helper_class>
 
 The class to use for the L</scroll_helper()> method. Defaults to
-L<Search::Elasticsearch::Scroll>.
+L<Search::Elasticsearch::Client::2_0::Scroll>.
 
 =head1 GENERAL METHODS
 
@@ -311,7 +311,7 @@ response, otherwise it throws an error.
 
     $indices_client = $e->indices;
 
-Returns an L<Search::Elasticsearch::Client::1_0::Direct::Indices> object which can be used
+Returns an L<Search::Elasticsearch::Client::2_0::Direct::Indices> object which can be used
 for managing indices, eg creating, deleting indices, managing mapping,
 index settings etc.
 
@@ -319,29 +319,36 @@ index settings etc.
 
     $cluster_client = $e->cluster;
 
-Returns an L<Search::Elasticsearch::Client::1_0::Direct::Cluster> object which can be used
+Returns an L<Search::Elasticsearch::Client::2_0::Direct::Cluster> object which can be used
 for managing the cluster, eg cluster-wide settings and cluster health.
 
 =head2 C<nodes()>
 
     $node_client = $e->nodes;
 
-Returns an L<Search::Elasticsearch::Client::1_0::Direct::Nodes> object which can be used
+Returns an L<Search::Elasticsearch::Client::2_0::Direct::Nodes> object which can be used
 to retrieve node info and stats.
 
 =head2 C<snapshot()>
 
     $snapshot_client = $e->snapshot;
 
-Returns an L<Search::Elasticsearch::Client::1_0::Direct::Snapshot> object which
+Returns an L<Search::Elasticsearch::Client::2_0::Direct::Snapshot> object which
 is used for managing backup repositories and creating and restoring
 snapshots.
 
+=head2 C<tasks()>
+
+    $tasks_client = $e->tasks;
+
+Returns an L<Search::Elasticsearch::Client::2_0::Direct::Tasks> object which
+is used for accessing the task management API.
+
 =head2 C<cat()>
 
     $cat_client = $e->cat;
 
-Returns an L<Search::Elasticsearch::Client::1_0::Direct::Cat> object which can be used
+Returns an L<Search::Elasticsearch::Client::2_0::Direct::Cat> object which can be used
 to retrieve simple to read text info for debugging and monitoring an
 Elasticsearch cluster.
 
@@ -368,7 +375,6 @@ Query string parameters:
     C<op_type>,
     C<parent>,
     C<refresh>,
-    C<replication>,
     C<routing>,
     C<timeout>,
     C<timestamp>,
@@ -398,7 +404,6 @@ Query string parameters:
     C<op_type>,
     C<parent>,
     C<refresh>,
-    C<replication>,
     C<routing>,
     C<timeout>,
     C<timestamp>,
@@ -500,7 +505,6 @@ Query string parameters:
     C<consistency>,
     C<parent>,
     C<refresh>,
-    C<replication>,
     C<routing>,
     C<timeout>,
     C<version>,
@@ -533,16 +537,53 @@ C<index>, C<type> and C<id> if it exists. Updates can be performed either by:
         }
     );
 
-=item * or with a script:
+=item * with an inline script:
 
     $response = $e->update(
         ...,
         body => {
-            script => "ctx._source.counter += incr",
-            params => { incr => 5 }
+            script => {
+                inline => "ctx._source.counter += incr",
+                params => { incr => 5 }
+            }
         }
     );
 
+Make sure you enable
+L<dynamic scripting|https://www.elastic.co/guide/en/elasticsearch/reference/current/modules-scripting.html#enable-dynamic-scripting>
+and know its implications.
+
+=item * with an indexed script:
+
+    $response = $e->update(
+        ...,
+        body => {
+            script => {
+                id     => $id,
+                params => { incr => 5 }
+            }
+        }
+    );
+
+See L<indexed scripts|https://www.elastic.co/guide/en/elasticsearch/reference/current/modules-scripting.html#_indexed_scripts>
+for more information.
+
+=item * with a script stored as a file:
+
+    $response = $e->update(
+        ...,
+        body => {
+            script => {
+                file   => 'counter',
+                lang   => 'groovy',
+                params => { incr => 5 }
+            }
+        }
+    );
+
+See L<scripting docs|https://www.elastic.co/guide/en/elasticsearch/reference/current/modules-scripting.html>
+for more information.
+
 =back
 
 Query string parameters:
@@ -552,7 +593,6 @@ Query string parameters:
     C<parent>,
     C<realtime>,
     C<refresh>,
-    C<replication>,
     C<retry_on_conflict>,
     C<routing>,
     C<script>,
@@ -614,7 +654,7 @@ that need to be made, bulk requests greatly improve performance.
         body    => [ actions ]          # required
     );
 
-See L<Search::Elasticsearch::Client::1_0::Bulk> and L</bulk_helper()> for a helper module that makes
+See L<Search::Elasticsearch::Client::2_0::Bulk> and L</bulk_helper()> for a helper module that makes
 bulk indexing simpler to use.
 
 The C<bulk()> method can perform multiple L</index()>, L</create()>,
@@ -677,8 +717,9 @@ cause the others to fail as well.
 
 Query string parameters:
     C<consistency>,
+    C<fields>,
     C<refresh>,
-    C<replication>,
+    C<routing>,
     C<timeout>
 
 See the L<bulk docs|http://www.elastic.co/guide/en/elasticsearch/reference/current/docs-bulk.html>
@@ -689,7 +730,7 @@ for more information.
     $bulk_helper = $e->bulk_helper( @args );
 
 Returns a new instance of the class specified in the L</bulk_helper_class>,
-which defaults to L<Search::Elasticsearch::Client::1_0::Bulk>.
+which defaults to L<Search::Elasticsearch::Client::2_0::Bulk>.
 
 =head2 C<mget()>
 
@@ -740,48 +781,6 @@ Query string parameters:
 See the L<mget docs|http://www.elastic.co/guide/en/elasticsearch/reference/current/docs-multi-get.html>
 for more information.
 
-=head2 C<delete_by_query()>
-
-    $result = $e->delete_by_query(
-        index => 'index' | \@indices,   # required
-        type  => 'type'  | \@types,     # optional
-
-        body  => { query }              # required
-
-    );
-
-The C<delete_by_query()> method deletes all documents which match the
-query.  For instance, to delete all documents from 2012:
-
-    $result = $e->delete_by_query(
-        body  => {
-            query => {
-                range => {
-                    date => {
-                        gte => '2012-01-01',
-                        lt  => '2013-01-01'
-                    }
-                }
-            }
-        }
-    );
-
-Query string parameters:
-    C<allow_no_indices>,
-    C<analyzer>,
-    C<consistency>,
-    C<default_operator>,
-    C<df>,
-    C<expand_wildcards>,
-    C<ignore_unavailable>,
-    C<q>,
-    C<replication>,
-    C<routing>,
-    C<timeout>
-
-See the L<delete_by_query docs|http://www.elastic.co/guide/en/elasticsearch/reference/current/docs-delete-by-query.html>
-for more information.
-
 =head2 C<mtermvectors()>
 
     $results = $e->mtermvectors(
@@ -882,7 +881,7 @@ Query string parameters:
     C<lowercase_expanded_terms>,
     C<preference>,
     C<q>,
-    C<query_cache>,
+    C<request_cache>,
     C<routing>,
     C<scroll>,
     C<search_type>,
@@ -925,7 +924,7 @@ Query string parameters:
     C<expand_wildcards>,
     C<ignore_unavailable>,
     C<lenient>,
-    C<lowercase_expanded_terms>,
+    C<lowercase_expanded_terms>
     C<min_score>,
     C<preference>,
     C<q>,
@@ -963,7 +962,7 @@ Query string parameters:
     C<expand_wildcards>,
     C<ignore_unavailable>,
     C<lenient>,
-    C<lowercase_expanded_terms>,
+    C<lowercase_expanded_terms>
     C<min_score>,
     C<preference>,
     C<q>,
@@ -986,7 +985,7 @@ within the C<body>) and parameters to use with the template, eg:
 
     $results = $e->search_template(
         body => {
-            template => {
+            inline => {
                 query => {
                     match => {
                         "{{my_field}}" => "{{my_value}}"
@@ -1013,6 +1012,36 @@ Query string parameters:
     C<scroll>,
     C<search_type>
 
+=head2 C<render_search_template()>
+
+    $response = $e->render_search_template(
+        id   => 'id',           # optional
+        body => { template }    # optional
+    );
+
+Renders the template, filling in the passed-in parameters and returns the resulting JSON, eg:
+
+    $results = $e->render_search_template(
+        body => {
+            inline => {
+                query => {
+                    match => {
+                        "{{my_field}}" => "{{my_value}}"
+                    }
+                },
+                size => "{{my_size}}"
+            },
+            params => {
+                my_field => 'foo',
+                my_value => 'bar',
+                my_size  => 5
+            }
+        }
+    );
+
+See the L<search template docs|http://www.elastic.co/guide/en/elasticsearch/reference/current/search-template.html>
+for more information.
+
 =head2 C<scroll()>
 
     $results = $e->scroll(
@@ -1029,7 +1058,7 @@ B<NOTE:> you will almost always want to set the
 C<search_type> to C<scan> in your
 original C<search()> request.
 
-See L</scroll_helper()> and L<Search::Elasticsearch::Scroll> for a helper utility
+See L</scroll_helper()> and L<Search::Elasticsearch::Client::2_0::Scroll> for a helper utility
 which makes managing scroll requests much easier.
 
 Query string parameters:
@@ -1060,7 +1089,7 @@ up resources on the server.
     $scroll_helper = $e->scroll_helper( @args );
 
 Returns a new instance of the class specified in the L</scroll_helper_class>,
-which defaults to L<Search::Elasticsearch::Scroll>.
+which defaults to L<Search::Elasticsearch::Client::2_0::Scroll>.
 
 =head2 C<msearch()>
 
@@ -1147,6 +1176,7 @@ for more information.
         index   => 'index'   | \@indices,   # optional
         fields  => 'field'   | \@fields,    # optional
         level   => 'cluster' | 'indices',   # optional
+        body    => { filters }              # optional
     );
 
 The C<field-stats> API returns statistical properties of a field
@@ -1183,6 +1213,127 @@ Query string parameters:
 See the L<search-shards docs|http://www.elastic.co/guide/en/elasticsearch/reference/current/search-shards.html>
 for more information.
 
+=head1 CRUD-BY-QUERY METHODS
+
+=head2 C<delete_by_query()>
+
+    $response = $e->delete_by_query(
+        index   => 'index' | \@indices,     # optional
+        type    => 'type'  | \@types,       # optional,
+        body    => { delete-by-query }      # optional
+    );
+
+The C<delete_by_query()> method (available with the
+L<delete-by-query plugin|https://www.elastic.co/guide/en/elasticsearch/plugins/current/plugins-delete-by-query.html>)
+deletes all documents which match the specified query.
+
+Query string parameters:
+    C<allow_no_indices>,
+    C<analyzer>,
+    C<default_operator>,
+    C<df>,
+    C<expand_wildcards>,
+    C<filter_path>,
+    C<ignore_unavailable>,
+    C<q>,
+    C<routing>,
+    C<timeout>
+
+See the L<delete-by-query docs|https://www.elastic.co/guide/en/elasticsearch/plugins/current/plugins-delete-by-query.html>
+for more information.
+
+=head2 C<reindex()>
+
+    $response = $e->reindex(
+        body => { reindex }     # required
+    );
+
+The C<reindex()> API is used to index documents from one index or multiple indices
+to a new index.
+
+Query string parameters:
+    C<consistency>,
+    C<refresh>,
+    C<requests_per_second>,
+    C<timeout>,
+    C<wait_for_completion>
+
+See the L<reindex docs|https://www.elastic.co/guide/en/elasticsearch/reference/current/docs-reindex.html>
+for more information.
+
+=head2 C<update_by_query()>
+
+    $response = $e->update_by_query(
+        index   => 'index' | \@indices,     # optional
+        type    => 'type'  | \@types,       # optional,
+        body    => { update-by-query }      # optional
+    );
+
+The C<update_by_query()> API is used to bulk update documents from one index or
+multiple indices using a script.
+
+Query string parameters:
+    C<_source>,
+    C<_source_exclude>,
+    C<_source_include>,
+    C<allow_no_indices>,
+    C<analyze_wildcard>,
+    C<analyzer>,
+    C<conflicts>,
+    C<consistency>,
+    C<default_operator>,
+    C<df>,
+    C<expand_wildcards>,
+    C<explain>,
+    C<fielddata_fields>,
+    C<fields>,
+    C<from>,
+    C<ignore_unavailable>,
+    C<lenient>,
+    C<lowercase_expanded_terms>,
+    C<preference>,
+    C<q>,
+    C<refresh>,
+    C<request_cache>,
+    C<requests_per_second>,
+    C<routing>,
+    C<scroll>,
+    C<scroll_size>,
+    C<search_timeout>,
+    C<search_type>,
+    C<size>,
+    C<sort>,
+    C<stats>,
+    C<suggest_field>,
+    C<suggest_mode>,
+    C<suggest_size>,
+    C<suggest_text>,
+    C<terminate_after>,
+    C<timeout>,
+    C<track_scores>,
+    C<version>,
+    C<version_type>,
+    C<wait_for_completion>
+
+See the L<update_by_query docs|https://www.elastic.co/guide/en/elasticsearch/reference/current/docs-update-by-query.html>
+for more information.
+
+=head2 C<reindex_rethrottle>
+
+    $response = $e->reindex_rethrottle(
+        task_id             => 'task_id',       # required
+        requests_per_second => $req_per_second
+    );
+
+The C<reindex_rethrottle()> API is used to dynamically update the throtting
+of an existing reindex request, identified by C<task_id>.
+
+Query string parameters:
+    C<requests_per_second>
+
+See the L<reindex docs|https://www.elastic.co/guide/en/elasticsearch/reference/current/docs-reindex.html>
+for more information.
+
 =head1 PERCOLATION METHODS
 
 =head2 C<percolate()>
@@ -1339,43 +1490,6 @@ Query string parameters:
     C<preference>,
     C<routing>
 
-=head2 C<mlt()>
-
-    $results = $e->mlt(
-        index   => 'my_index',  # required
-        type    => 'my_type',   # required
-        id      => 123,         # required
-
-        body    => { search }   # optional
-    );
-
-The C<mlt()> method runs a
-L<more-like-this query|http://www.elastic.co/guide/en/elasticsearch/reference/current/query-dsl-mlt-query.html>
-to find other documents which are similar to the specified document.
-
-Query string parameters:
-    C<boost_terms>,
-    C<max_doc_freq>,
-    C<max_query_terms>,
-    C<max_word_length>,
-    C<min_doc_freq>,
-    C<min_term_freq>,
-    C<min_word_length>,
-    C<mlt_fields>,
-    C<percent_terms_to_match>,
-    C<routing>,
-    C<search_from>,
-    C<search_indices>,
-    C<search_scroll>,
-    C<search_size>,
-    C<search_source>,
-    C<search_type>,
-    C<search_types>,
-    C<stop_words>
-
-See the L<mlt docs|http://www.elastic.co/guide/en/elasticsearch/reference/current/search-more-like-this.html>
-for more information.
-
 =head1 INDEXED SCRIPT METHODS
 
 If dynamic scripting is enabled, Elasticsearch allows you to store scripts in an internal index known as
@@ -1497,11 +1611,11 @@ See the L<indexed search template docs|http://www.elastic.co/guide/en/elasticsea
 
 =head1 AUTHOR
 
-Enrico Zimuel <enrico.zimuel@elastic.co>
+Clinton Gormley <drtech@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2020 by Elasticsearch BV.
+This software is Copyright (c) 2016 by Elasticsearch BV.
 
 This is free software, licensed under:
 
@@ -1511,5 +1625,5 @@ This is free software, licensed under:
 
 __END__
 
-# ABSTRACT: Thin client with full support for Elasticsearch 1.x APIs
+# ABSTRACT: Thin client with full support for Elasticsearch 2.x APIs
 
