@@ -1,13 +1,7 @@
-# Licensed to Elasticsearch B.V under one or more agreements.
-# Elasticsearch B.V licenses this file to you under the Apache 2.0 License.
-# See the LICENSE file in the project root for more information
-
-package Search::Elasticsearch::Client::1_0::Direct::Cat;
-$Search::Elasticsearch::Client::1_0::Direct::Cat::VERSION = '7.30_1'; # TRIAL
-
-$Search::Elasticsearch::Client::1_0::Direct::Cat::VERSION = '7.301';
+package Search::Elasticsearch::Client::2_0::Direct::Cat;
+$Search::Elasticsearch::Client::2_0::Direct::Cat::VERSION = '5.00';
 use Moo;
-with 'Search::Elasticsearch::Client::1_0::Role::API';
+with 'Search::Elasticsearch::Client::2_0::Role::API';
 with 'Search::Elasticsearch::Role::Client::Direct';
 use Search::Elasticsearch::Util qw(parse_params);
 use namespace::clean;
@@ -30,11 +24,11 @@ sub help {
 
 =head1 NAME
 
-Search::Elasticsearch::Client::1_0::Direct::Cat - A client for running cat debugging requests
+Search::Elasticsearch::Client::2_0::Direct::Cat - A client for running cat debugging requests
 
 =head1 VERSION
 
-version 7.30_1
+version 5.00
 
 =head1 DESCRIPTION
 
@@ -215,6 +209,22 @@ Query string parameters:
 See the L<cat master docs|http://www.elastic.co/guide/en/elasticsearch/reference/current/cat-master.html>
 for more information.
 
+=head2 C<nodeattrs()>
+
+    say $e->cat->nodeattrs();
+
+Returns the node attributes set per node.
+
+Query string parameters:
+    C<h>,
+    C<help>,
+    C<local>,
+    C<master_timeout>,
+    C<v>
+
+See the L<cat nodeattrs docs|http://www.elastic.co/guide/en/elasticsearch/reference/current/cat-nodeattrs.html>
+for more information.
+
 =head2 C<nodes()>
 
     say $e->cat->nodes();
@@ -269,7 +279,7 @@ for more information.
         index => 'index' | \@indices    # optional
     );
 
-Provides a is a view of shard replication. It will show information
+Provides a view of shard replication. It will show information
 anytime data from at least one shard is copying to a different node.
 It can also show up on cluster restarts. If your recovery process seems
 stuck, try it to see if there’s any movement using C<recovery()>.
@@ -284,6 +294,22 @@ Query string parameters:
 See the L<cat recovery docs|http://www.elastic.co/guide/en/elasticsearch/reference/current/cat-recovery.html>
 for more information.
 
+=head2 C<repositories()>
+
+    say $e->cat->repositories()
+
+Provides a list of registered snapshot repositories.
+
+Query string parameters:
+    C<h>,
+    C<help>,
+    C<local>,
+    C<master_timeout>,
+    C<v>
+
+See the L<cat repositories docs|http://www.elastic.co/guide/en/elasticsearch/reference/current/cat-repositories.html>
+for more information.
+
 =head2 C<segments()>
 
     say $e->cat->segments(
@@ -319,6 +345,24 @@ Query string parameters:
 See the L<cat shards docs|http://www.elastic.co/guide/en/elasticsearch/reference/current/cat-shards.html>
 for more information.
 
+=head2 C<snapshots()>
+
+    say $e->cat->snapshots(
+        repository => 'repository' | \@repositories # required
+    )
+
+Provides a list of all snapshots that belong to the specified repositories.
+
+Query string parameters:
+    C<h>,
+    C<help>,
+    C<ignore_unavailable>,
+    C<master_timeout>,
+    C<v>
+
+See the L<cat snapshots docs|http://www.elastic.co/guide/en/elasticsearch/reference/current/cat-snapshots.html>
+for more information.
+
 =head2 C<thread_pool()>
 
     say $e->cat->thread_pool(
@@ -342,11 +386,11 @@ for more information.
 
 =head1 AUTHOR
 
-Enrico Zimuel <enrico.zimuel@elastic.co>
+Clinton Gormley <drtech@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2020 by Elasticsearch BV.
+This software is Copyright (c) 2016 by Elasticsearch BV.
 
 This is free software, licensed under:
 
