@@ -1,28 +1,10 @@
-# Licensed to Elasticsearch B.V under one or more agreements.
-# Elasticsearch B.V licenses this file to you under the Apache 2.0 License.
-# See the LICENSE file in the project root for more information
-
-package Search::Elasticsearch::Client::1_0::Direct::Cluster;
-$Search::Elasticsearch::Client::1_0::Direct::Cluster::VERSION = '7.30_1'; # TRIAL
-
-$Search::Elasticsearch::Client::1_0::Direct::Cluster::VERSION = '7.301';
+package Search::Elasticsearch::Client::2_0::Direct::Cluster;
+$Search::Elasticsearch::Client::2_0::Direct::Cluster::VERSION = '5.00';
 use Moo;
-with 'Search::Elasticsearch::Client::1_0::Role::API';
+with 'Search::Elasticsearch::Client::2_0::Role::API';
 with 'Search::Elasticsearch::Role::Client::Direct';
 __PACKAGE__->_install_api('cluster');
 
-sub node_info     { _deprecated( 'node_info',     'info' ) }
-sub node_stats    { _deprecated( 'node_stats',    'stats' ) }
-sub hot_threads   { _deprecated( 'hot_threads',   'hot_threads' ) }
-sub node_shutdown { _deprecated( 'node_shutdown', 'shutdown' ) }
-
-#===================================
-sub _deprecated {
-#===================================
-    my ( $old, $new ) = @_;
-    die "The method \$es->cluster->$old() has moved to \$es->nodes->$new()";
-}
-
 1;
 
 =pod
@@ -31,11 +13,11 @@ sub _deprecated {
 
 =head1 NAME
 
-Search::Elasticsearch::Client::1_0::Direct::Cluster - A client for running cluster-level requests
+Search::Elasticsearch::Client::2_0::Direct::Cluster - A client for running cluster-level requests
 
 =head1 VERSION
 
-version 7.30_1
+version 5.00
 
 =head1 DESCRIPTION
 
@@ -80,7 +62,8 @@ Returns high-level cluster stats, optionally limited to the listed nodes.
 
 Query string parameters:
     C<flat_settings>,
-    C<human>
+    C<human>,
+    C<timeout>
 
 See the L<cluster stats docs|http://www.elastic.co/guide/en/elasticsearch/reference/current/cluster-stats.html>
 for more information.
@@ -206,11 +189,11 @@ for more information.
 
 =head1 AUTHOR
 
-Enrico Zimuel <enrico.zimuel@elastic.co>
+Clinton Gormley <drtech@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2020 by Elasticsearch BV.
+This software is Copyright (c) 2016 by Elasticsearch BV.
 
 This is free software, licensed under:
 
