@@ -1,13 +1,7 @@
-# Licensed to Elasticsearch B.V under one or more agreements.
-# Elasticsearch B.V licenses this file to you under the Apache 2.0 License.
-# See the LICENSE file in the project root for more information
-
-package Search::Elasticsearch::Client::1_0::Direct::Indices;
-$Search::Elasticsearch::Client::1_0::Direct::Indices::VERSION = '7.30_1'; # TRIAL
-
-$Search::Elasticsearch::Client::1_0::Direct::Indices::VERSION = '7.301';
+package Search::Elasticsearch::Client::2_0::Direct::Indices;
+$Search::Elasticsearch::Client::2_0::Direct::Indices::VERSION = '5.00';
 use Moo;
-with 'Search::Elasticsearch::Client::1_0::Role::API';
+with 'Search::Elasticsearch::Client::2_0::Role::API';
 with 'Search::Elasticsearch::Role::Client::Direct';
 __PACKAGE__->_install_api('indices');
 
@@ -19,11 +13,11 @@ __PACKAGE__->_install_api('indices');
 
 =head1 NAME
 
-Search::Elasticsearch::Client::1_0::Direct::Indices - A client for running index-level requests
+Search::Elasticsearch::Client::2_0::Direct::Indices - A client for running index-level requests
 
 =head1 VERSION
 
-version 7.30_1
+version 5.00
 
 =head1 DESCRIPTION
 
@@ -52,7 +46,8 @@ settings, type mappings and index warmers can be added at the same time.
 
 Query string parameters:
     C<master_timeout>,
-    C<timeout>
+    C<timeout>,
+    C<update_all_types>
 
 See the L<create index docs|http://www.elastic.co/guide/en/elasticsearch/reference/current/indices-create-index.html>
 for more information.
@@ -73,6 +68,7 @@ See the L<get index docs|http://www.elastic.co/guide/en/elasticsearch/reference/
 Query string parameters:
     C<allow_no_indices>,
     C<expand_wildcards>,
+    C<human>,
     C<ignore_unavailable>,
     C<local>
 
@@ -163,14 +159,10 @@ Query string parameters:
     C<expand_wildcards>,
     C<fielddata>,
     C<fields>,
-    C<filter>,
-    C<filter_cache>,
-    C<filter_keys>,
-    C<id>,
-    C<id_cache>,
     C<ignore_unavailable>,
-    C<query_cache>,
-    C<recycler>
+    C<query>,
+    C<recycler>,
+    C<request>
 
 See the L<clear_cache docs|http://www.elastic.co/guide/en/elasticsearch/reference/current/indices-clearcache.html>
 for more information.
@@ -208,7 +200,6 @@ Query string parameters:
     C<allow_no_indices>,
     C<expand_wildcards>,
     C<force>,
-    C<full>,
     C<ignore_unavailable>,
     C<wait_if_ongoing>
 
@@ -232,11 +223,40 @@ Synced flushes happens automatically in the background on indices that have not
 writes for a while, but the L<flush_synced()> method can be used to trigger this process
 manually, eg before shutting down.  Any new commits immediately break the sync.
 
-See the L<flush synced docs|http://www.elastic.co/guide/en/elasticsearch/reference/current/flush.html>
+See the L<flush synced docs|http://www.elastic.co/guide/en/elasticsearch/reference/current/indices-synced-flush.html>
+for more information.
+
+Query string parameters:
+    C<allow_no_indices>,
+    C<expand_wildcards>,
+    C<ignore_unavailable>
+
+=head2 C<forcemerge()>
+
+    $response = $e->indices->forcemerge(
+        index => 'index' | \@indices    # optional
+    );
+
+The C<forcemerge()> method rewrites all the data in an index into at most
+C<max_num_segments>.  This is a very heavy operation and should only be run
+with care, and only on indices that are no longer being updated.
+
+Query string parameters:
+    C<allow_no_indices>,
+    C<expand_wildcards>,
+    C<flush>,
+    C<ignore_unavailable>,
+    C<max_num_segments>,
+    C<only_expunge_deletes>,
+    C<wait_for_merge>
+
+See the L<forcemerge docs|http://www.elastic.co/guide/en/elasticsearch/reference/current/indices-forcemerge.html>
 for more information.
 
 =head2 C<optimize()>
 
+The C<optimize()> method is deprecated in 2.x and will be replaced by L<forcemerge()>;
+
     $response = $e->indices->optimize(
         index => 'index' | \@indices    # optional
     );
@@ -327,9 +347,9 @@ Query string parameters:
     C<allow_no_indices>,
     C<expand_wildcards>,
     C<ignore_unavailable>,
-    C<ignore_conflicts>,
     C<master_timeout>,
-    C<timeout>
+    C<timeout>,
+    C<update_all_types>
 
 See the L<put_mapping docs|http://www.elastic.co/guide/en/elasticsearch/reference/current/indices-put-mapping.html>
 for more information.
@@ -356,9 +376,9 @@ for more information.
 =head2 C<get_field_mapping()>
 
     $result = $e->indices->get_field_mapping(
-        index => 'index' | \@indices    # optional,
-        type  => 'type'  | \@types      # optional,
-        field => 'field' | \@fields     # required
+        index => 'index'  | \@indices    # optional,
+        type  => 'type'   | \@types      # optional,
+        fields => 'field' | \@fields     # required
 
         include_defaults => 0 | 1
     );
@@ -395,22 +415,6 @@ Query string parameters:
 See the L<exists_type docs|http://www.elastic.co/guide/en/elasticsearch/reference/current/indices-types-exists.html>
 for more information.
 
-=head2 C<delete_mapping()>
-
-    $response = $e->indices->delete_mapping(
-        index => 'index' | \@indices    # required,
-        type  => 'type'  | \@types      # required
-    );
-
-The C<delete_mapping()> method deletes the type mappings (and all documents of
-that type) in all specified indices.
-
-Query string parameters:
-    C<master_timeout>
-
-See the L<delete_mapping docs|http://www.elastic.co/guide/en/elasticsearch/reference/current/indices-delete-mapping.html>
-for more information.
-
 =head1 ALIAS METHODS
 
 =head2 C<update_aliases()>
@@ -579,6 +583,7 @@ Query string parameters:
     C<allow_no_indices>,
     C<expand_wildcards>,
     C<flat_settings>,
+    C<human>,
     C<ignore_unavailable>,
     C<local>
 
@@ -612,7 +617,7 @@ for more information.
 =head2 C<get_template()>
 
     $result = $e->indices->get_template(
-        name  => 'template'                 # optional
+        name  => 'template' | \@templates # optional
     );
 
 The C<get_template()> method is used to retrieve a named template.
@@ -685,7 +690,8 @@ Query string parameters:
     C<allow_no_indices>,
     C<expand_wildcards>,
     C<ignore_unavailable>,
-    C<master_timeout>
+    C<master_timeout>,
+    C<request_cache>
 
 See the L<put_warmer docs|http://www.elastic.co/guide/en/elasticsearch/reference/current/indices-warmers.html>
 for more information.
@@ -751,6 +757,7 @@ Allowed metrics are:
     C<percolate>,
     C<query_cache>,
     C<refresh>,
+    C<request_cache>,
     C<search>,
     C<segments>,
     C<store>,
@@ -797,11 +804,31 @@ Query string parameters:
     C<allow_no_indices>,
     C<expand_wildcards>,
     C<human>,
-    C<ignore_unavailable>
+    C<ignore_unavailable>,
+    C<verbose>
 
 See the L<segments docs|http://www.elastic.co/guide/en/elasticsearch/reference/current/indices-segments.html>
 for more information.
 
+=head2 C<shard_stores()>
+
+    $result = $e->indices->shard_stores(
+        index   => 'index' | \@indices      # optional
+    );
+
+The C<shard_stores()> method is used to find out which nodes contain
+copies of which shards, whether the shards are allocated or not.
+
+Query string parameters:
+    C<allow_no_indices>,
+    C<expand_wildcards>,
+    C<human>,
+    C<ignore_unavailable>,
+    C<status>
+
+See the L<shard_stores docs|http://www.elastic.co/guide/en/elasticsearch/reference/current/indices-shards-stores.html>
+for more information.
+
 =head1 QUERY AND ANALYSIS METHODS
 
 =head2 C<analyze()>
@@ -818,12 +845,13 @@ for debugging analyzer configurations.
 
 Query string parameters:
     C<analyzer>,
-    C<char_filters>,
+    C<attributes>,
+    C<char_filter>,
+    C<explain>,
     C<field>,
-    C<filters>,
+    C<filter>,
     C<format>,
     C<prefer_local>,
-    C<rewrite>,
     C<text>,
     C<tokenizer>
 
@@ -849,23 +877,24 @@ Query string parameters:
     C<analyzer>,
     C<default_operator>,
     C<df>,
-    C<expand_wildcards>,
     C<explain>,
+    C<expand_wildcards>,
     C<ignore_unavailable>,
     C<lenient>,
-    C<lowercase_expanded_terms>,
-    C<q>
+    C<lowercase_expanded_terms>
+    C<q>,
+    C<rewrite>
 
 See the L<validate_query docs|http://www.elastic.co/guide/en/elasticsearch/reference/current/indices-validate.html>
 for more information.
 
 =head1 AUTHOR
 
-Enrico Zimuel <enrico.zimuel@elastic.co>
+Clinton Gormley <drtech@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2020 by Elasticsearch BV.
+This software is Copyright (c) 2016 by Elasticsearch BV.
 
 This is free software, licensed under:
 
