@@ -1,13 +1,7 @@
-# Licensed to Elasticsearch B.V under one or more agreements.
-# Elasticsearch B.V licenses this file to you under the Apache 2.0 License.
-# See the LICENSE file in the project root for more information
-
-package Search::Elasticsearch::Client::1_0::Direct::Nodes;
-$Search::Elasticsearch::Client::1_0::Direct::Nodes::VERSION = '7.30_1'; # TRIAL
-
-$Search::Elasticsearch::Client::1_0::Direct::Nodes::VERSION = '7.301';
+package Search::Elasticsearch::Client::2_0::Direct::Nodes;
+$Search::Elasticsearch::Client::2_0::Direct::Nodes::VERSION = '5.00';
 use Moo;
-with 'Search::Elasticsearch::Client::1_0::Role::API';
+with 'Search::Elasticsearch::Client::2_0::Role::API';
 with 'Search::Elasticsearch::Role::Client::Direct';
 __PACKAGE__->_install_api('nodes');
 
@@ -19,11 +13,11 @@ __PACKAGE__->_install_api('nodes');
 
 =head1 NAME
 
-Search::Elasticsearch::Client::1_0::Direct::Nodes - A client for running node-level requests
+Search::Elasticsearch::Client::2_0::Direct::Nodes - A client for running node-level requests
 
 =head1 VERSION
 
-version 7.30_1
+version 5.00
 
 =head1 DESCRIPTION
 
@@ -54,6 +48,7 @@ Allowed metrics are:
     C<process>,
     C<settings>,
     C<thread_pool>,
+    C<timeout>,
     C<transport>
 
 Query string parameters:
@@ -90,10 +85,11 @@ Allowed metrics are:
     C<os>,
     C<process>,
     C<thread_pool>,
+    C<timeout>,
     C<transport>
 
 If the C<indices> metric (or C<_all>) is specified, then
-L<indices_stats|Search::Elasticsearch::Client::1_0::Direct::Indices/indices_stats()>
+L<indices_stats|Search::Elasticsearch::Client::2_0::Direct::Indices/indices_stats()>
 information is returned on a per-node basis. Which indices stats are
 returned can be controlled with the C<index_metric> parameter:
 
@@ -148,34 +144,19 @@ Query string parameters:
     C<interval>,
     C<snapshots>,
     C<threads>,
+    C<timeout>,
     C<type>
 
 See the L<hot_threads docs|http://www.elastic.co/guide/en/elasticsearch/reference/current/cluster-nodes-hot-threads.html>
 for more information.
 
-=head2 C<shutdown()>
-
-    $e->nodes->shutdown(
-        node_id => $node_id | \@node_ids    # optional
-    );
-
-The C<shutdown()> method is used to shutdown one or more nodes, or the whole
-cluster.
-
-Query string parameters:
-    C<delay>,
-    C<exit>
-
-See the L<shutdown docs|http://www.elastic.co/guide/en/elasticsearch/reference/current/cluster-nodes-shutdown.html>
-for more information.
-
 =head1 AUTHOR
 
-Enrico Zimuel <enrico.zimuel@elastic.co>
+Clinton Gormley <drtech@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2020 by Elasticsearch BV.
+This software is Copyright (c) 2016 by Elasticsearch BV.
 
 This is free software, licensed under:
 
