@@ -1,13 +1,7 @@
-# Licensed to Elasticsearch B.V under one or more agreements.
-# Elasticsearch B.V licenses this file to you under the Apache 2.0 License.
-# See the LICENSE file in the project root for more information
-
-package Search::Elasticsearch::Client::1_0::Direct::Snapshot;
-$Search::Elasticsearch::Client::1_0::Direct::Snapshot::VERSION = '7.30_1'; # TRIAL
-
-$Search::Elasticsearch::Client::1_0::Direct::Snapshot::VERSION = '7.301';
+package Search::Elasticsearch::Client::2_0::Direct::Snapshot;
+$Search::Elasticsearch::Client::2_0::Direct::Snapshot::VERSION = '5.00';
 use Moo;
-with 'Search::Elasticsearch::Client::1_0::Role::API';
+with 'Search::Elasticsearch::Client::2_0::Role::API';
 with 'Search::Elasticsearch::Role::Client::Direct';
 __PACKAGE__->_install_api('snapshot');
 
@@ -19,11 +13,11 @@ __PACKAGE__->_install_api('snapshot');
 
 =head1 NAME
 
-Search::Elasticsearch::Client::1_0::Direct::Snapshot - A client for managing snapshot/restore
+Search::Elasticsearch::Client::2_0::Direct::Snapshot - A client for managing snapshot/restore
 
 =head1 VERSION
 
-version 7.30_1
+version 5.00
 
 =head1 DESCRIPTION
 
@@ -178,11 +172,11 @@ for more information.
 
 =head1 AUTHOR
 
-Enrico Zimuel <enrico.zimuel@elastic.co>
+Clinton Gormley <drtech@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2020 by Elasticsearch BV.
+This software is Copyright (c) 2016 by Elasticsearch BV.
 
 This is free software, licensed under:
 
