@@ -1,18 +1,12 @@
-# Licensed to Elasticsearch B.V under one or more agreements.
-# Elasticsearch B.V licenses this file to you under the Apache 2.0 License.
-# See the LICENSE file in the project root for more information
-
-package Search::Elasticsearch::Client::1_0::Role::API;
-$Search::Elasticsearch::Client::1_0::Role::API::VERSION = '7.30_1'; # TRIAL
-
-$Search::Elasticsearch::Client::1_0::Role::API::VERSION = '7.301';
+package Search::Elasticsearch::Client::2_0::Role::API;
+$Search::Elasticsearch::Client::2_0::Role::API::VERSION = '5.00';
 use Moo::Role;
 with 'Search::Elasticsearch::Role::API';
 
 use Search::Elasticsearch::Util qw(throw);
 use namespace::clean;
 
-has 'api_version' => ( is => 'ro', default => '1_0' );
+has 'api_version' => ( is => 'ro', default => '2_0' );
 
 our %API;
 
@@ -27,6 +21,7 @@ sub api {
 #===================================
 %API = (
 #===================================
+
     'bulk.metadata' => {
         params => [
             'index',   'type',   'id',        'fields',
@@ -60,9 +55,9 @@ sub api {
         ],
         qs => {
             consistency => "enum",
+            fields      => "list",
             filter_path => "list",
             refresh     => "boolean",
-            replication => "enum",
             routing     => "string",
             timeout     => "time",
         },
@@ -159,7 +154,6 @@ sub api {
             filter_path  => "list",
             parent       => "string",
             refresh      => "boolean",
-            replication  => "enum",
             routing      => "string",
             timeout      => "time",
             version      => "number",
@@ -169,7 +163,7 @@ sub api {
 
     'delete_by_query' => {
         body   => {},
-        doc    => "docs-delete-by-query",
+        doc    => "plugins-delete-by-query",
         method => "DELETE",
         parts  => {
             index => { multi => 1, required => 1 },
@@ -182,14 +176,12 @@ sub api {
         qs => {
             allow_no_indices   => "boolean",
             analyzer           => "string",
-            consistency        => "enum",
             default_operator   => "enum",
             df                 => "string",
             expand_wildcards   => "enum",
             filter_path        => "list",
             ignore_unavailable => "boolean",
             q                  => "string",
-            replication        => "enum",
             routing            => "string",
             timeout            => "time",
         },
@@ -210,7 +202,7 @@ sub api {
     'delete_template' => {
         doc    => "search-template",
         method => "DELETE",
-        parts  => { id => {} },
+        parts  => { id => { required => 1 } },
         paths  => [ [ { id => 2 }, "_search", "template", "{id}" ] ],
         qs     => {
             filter_path  => "list",
@@ -275,6 +267,7 @@ sub api {
     },
 
     'field_stats' => {
+        body  => {},
         doc   => "search-field-stats",
         parts => { index => { multi => 1 } },
         paths => [
@@ -389,7 +382,6 @@ sub api {
             op_type      => "enum",
             parent       => "string",
             refresh      => "boolean",
-            replication  => "enum",
             routing      => "string",
             timeout      => "time",
             timestamp    => "time",
@@ -427,42 +419,6 @@ sub api {
         },
     },
 
-    'mlt' => {
-        body  => {},
-        doc   => "search-more-like-this",
-        parts => {
-            id    => { required => 1 },
-            index => { required => 1 },
-            type  => { required => 1 },
-        },
-        paths => [
-            [   { id => 2, index => 0, type => 1 },
-                "{index}", "{type}", "{id}", "_mlt",
-            ],
-        ],
-        qs => {
-            boost_terms            => "number",
-            filter_path            => "list",
-            max_doc_freq           => "number",
-            max_query_terms        => "number",
-            max_word_length        => "number",
-            min_doc_freq           => "number",
-            min_term_freq          => "number",
-            min_word_length        => "number",
-            mlt_fields             => "list",
-            percent_terms_to_match => "number",
-            routing                => "string",
-            search_from            => "number",
-            search_indices         => "list",
-            search_scroll          => "string",
-            search_size            => "number",
-            search_source          => "string",
-            search_type            => "string",
-            search_types           => "list",
-            stop_words             => "list",
-        },
-    },
-
     'mpercolate' => {
         body => { required => 1 },
         doc  => "search-percolate",
@@ -518,6 +474,8 @@ sub api {
             realtime         => "boolean",
             routing          => "string",
             term_statistics  => "boolean",
+            version          => "number",
+            version_type     => "enum",
         },
     },
 
@@ -589,6 +547,42 @@ sub api {
         },
     },
 
+    'reindex' => {
+        body   => { required => 1 },
+        doc    => "plugins-reindex",
+        method => "POST",
+        parts  => {},
+        paths => [ [ {}, "_reindex" ] ],
+        qs => {
+            consistency         => "enum",
+            filter_path         => "list",
+            refresh             => "boolean",
+            requests_per_second => "number",
+            timeout             => "time",
+            wait_for_completion => "boolean",
+        },
+    },
+
+    'reindex_rethrottle' => {
+        doc    => "docs-reindex",
+        method => "POST",
+        parts  => { task_id => {} },
+        paths =>
+            [ [ { task_id => 1 }, "_reindex", "{task_id}", "_rethrottle" ] ],
+        qs => { filter_path => "list", requests_per_second => "number" },
+    },
+
+    'render_search_template' => {
+        body  => {},
+        doc   => "search-template",
+        parts => { id => {} },
+        paths => [
+            [ { id => 2 }, "_render", "template", "{id}" ],
+            [ {}, "_render", "template" ],
+        ],
+        qs => { filter_path => "list" },
+    },
+
     'scroll' => {
         body  => {},
         doc   => "search-request-scroll",
@@ -629,7 +623,7 @@ sub api {
             lowercase_expanded_terms => "boolean",
             preference               => "string",
             q                        => "string",
-            query_cache              => "boolean",
+            request_cache            => "boolean",
             routing                  => "list",
             scroll                   => "time",
             search_type              => "enum",
@@ -640,6 +634,7 @@ sub api {
             suggest_mode             => "enum",
             suggest_size             => "number",
             suggest_text             => "string",
+            terminate_after          => "number",
             timeout                  => "time",
             track_scores             => "boolean",
             version                  => "boolean",
@@ -679,7 +674,7 @@ sub api {
 
     'search_shards' => {
         doc   => "search-shards",
-        parts => { index => {}, type => {} },
+        parts => { index => { multi => 1 }, type => { multi => 1 } },
         paths => [
             [   { index => 0, type => 1 }, "{index}",
                 "{type}", "_search_shards",
@@ -739,7 +734,7 @@ sub api {
         },
     },
 
-    'termvector' => {
+    'termvectors' => {
         body  => {},
         doc   => "docs-termvectors",
         parts => {
@@ -750,11 +745,14 @@ sub api {
         paths => [
             [   { id => 2, index => 0, type => 1 }, "{index}",
                 "{type}", "{id}",
-                "_termvector",
+                "_termvectors",
+            ],
+            [   { index => 0, type => 1 }, "{index}", "{type}",
+                "_termvectors"
             ],
-            [ { index => 0, type => 1 }, "{index}", "{type}", "_termvector" ],
         ],
         qs => {
+            dfs              => "boolean",
             field_statistics => "boolean",
             fields           => "list",
             filter_path      => "list",
@@ -766,6 +764,8 @@ sub api {
             realtime         => "boolean",
             routing          => "string",
             term_statistics  => "boolean",
+            version          => "number",
+            version_type     => "enum",
         },
     },
 
@@ -790,7 +790,6 @@ sub api {
             lang              => "string",
             parent            => "string",
             refresh           => "boolean",
-            replication       => "enum",
             retry_on_conflict => "number",
             routing           => "string",
             script            => "string",
@@ -804,6 +803,66 @@ sub api {
         },
     },
 
+    'update_by_query' => {
+        body   => {},
+        doc    => "plugins-reindex",
+        method => "POST",
+        parts  => {
+            index => { multi => 1, required => 1 },
+            type  => { multi => 1 }
+        },
+        paths => [
+            [   { index => 0, type => 1 }, "{index}",
+                "{type}", "_update_by_query",
+            ],
+            [ { index => 0 }, "{index}", "_update_by_query" ],
+        ],
+        qs => {
+            _source                  => "list",
+            _source_exclude          => "list",
+            _source_include          => "list",
+            allow_no_indices         => "boolean",
+            analyze_wildcard         => "boolean",
+            analyzer                 => "string",
+            conflicts                => "enum",
+            consistency              => "enum",
+            default_operator         => "enum",
+            df                       => "string",
+            expand_wildcards         => "enum",
+            explain                  => "boolean",
+            fielddata_fields         => "list",
+            fields                   => "list",
+            filter_path              => "list",
+            from                     => "number",
+            ignore_unavailable       => "boolean",
+            lenient                  => "boolean",
+            lowercase_expanded_terms => "boolean",
+            preference               => "string",
+            q                        => "string",
+            refresh                  => "boolean",
+            request_cache            => "boolean",
+            requests_per_second      => "number",
+            routing                  => "list",
+            scroll                   => "time",
+            scroll_size              => "number",
+            search_timeout           => "time",
+            search_type              => "enum",
+            size                     => "number",
+            sort                     => "list",
+            stats                    => "list",
+            suggest_field            => "string",
+            suggest_mode             => "enum",
+            suggest_size             => "number",
+            suggest_text             => "string",
+            terminate_after          => "number",
+            timeout                  => "time",
+            track_scores             => "boolean",
+            version                  => "boolean",
+            version_type             => "boolean",
+            wait_for_completion      => "boolean",
+        },
+    },
+
     'cat.aliases' => {
         doc   => "cat-alias",
         parts => { name => { multi => 1 } },
@@ -922,6 +981,19 @@ sub api {
         },
     },
 
+    'cat.nodeattrs' => {
+        doc   => "cat-nodeattrs",
+        parts => {},
+        paths => [ [ {}, "_cat", "nodeattrs" ] ],
+        qs    => {
+            h              => "list",
+            help           => "boolean",
+            local          => "boolean",
+            master_timeout => "time",
+            v              => "boolean",
+        },
+    },
+
     'cat.nodes' => {
         doc   => "cat-nodes",
         parts => {},
@@ -977,6 +1049,19 @@ sub api {
         },
     },
 
+    'cat.repositories' => {
+        doc   => "cat-repositories",
+        parts => {},
+        paths => [ [ {}, "_cat", "repositories" ] ],
+        qs    => {
+            h              => "list",
+            help           => "boolean",
+            local          => "boolean",
+            master_timeout => "time",
+            v              => "boolean",
+        },
+    },
+
     'cat.segments' => {
         doc   => "cat-segments",
         parts => { index => { multi => 1 } },
@@ -1003,6 +1088,20 @@ sub api {
         },
     },
 
+    'cat.snapshots' => {
+        doc   => "cat-snapshots",
+        parts => { repository => { multi => 1, required => 1 } },
+        paths =>
+            [ [ { repository => 2 }, "_cat", "snapshots", "{repository}" ] ],
+        qs => {
+            h                  => "list",
+            help               => "boolean",
+            ignore_unavailable => "boolean",
+            master_timeout     => "time",
+            v                  => "boolean",
+        },
+    },
+
     'cat.thread_pool' => {
         doc   => "cat-thread-pool",
         parts => {},
@@ -1031,7 +1130,7 @@ sub api {
 
     'cluster.health' => {
         doc   => "cluster-health",
-        parts => { index => {} },
+        parts => { index => { multi => 1 } },
         paths => [
             [ { index => 2 }, "_cluster", "health", "{index}" ],
             [ {}, "_cluster", "health" ],
@@ -1135,13 +1234,17 @@ sub api {
             [ [ { index => 0 }, "{index}", "_analyze" ], [ {}, "_analyze" ] ],
         qs => {
             analyzer     => "string",
+            attributes   => "list",
+            char_filter  => "list",
             char_filters => "list",
+            explain      => "boolean",
             field        => "string",
+            filter       => "list",
             filter_path  => "list",
             filters      => "list",
             format       => "enum",
             prefer_local => "boolean",
-            text         => "string",
+            text         => "list",
             tokenizer    => "string",
         },
     },
@@ -1159,22 +1262,18 @@ sub api {
             expand_wildcards   => "enum",
             fielddata          => "boolean",
             fields             => "list",
-            filter             => "boolean",
-            filter_cache       => "boolean",
-            filter_keys        => "boolean",
             filter_path        => "list",
-            id                 => "boolean",
-            id_cache           => "boolean",
             ignore_unavailable => "boolean",
-            query_cache        => "boolean",
+            query              => "boolean",
             recycler           => "boolean",
+            request            => "boolean",
         },
     },
 
     'indices.close' => {
         doc    => "indices-open-close",
         method => "POST",
-        parts  => { index => { required => 1 } },
+        parts  => { index => { multi => 1, required => 1 } },
         paths  => [ [ { index => 0 }, "{index}", "_close" ] ],
         qs     => {
             allow_no_indices   => "boolean",
@@ -1193,9 +1292,10 @@ sub api {
         parts  => { index => { required => 1 } },
         paths  => [ [ { index => 0 }, "{index}" ] ],
         qs     => {
-            filter_path    => "list",
-            master_timeout => "time",
-            timeout        => "time"
+            filter_path      => "list",
+            master_timeout   => "time",
+            timeout          => "time",
+            update_all_types => "boolean",
         },
     },
 
@@ -1227,19 +1327,6 @@ sub api {
         },
     },
 
-    'indices.delete_mapping' => {
-        doc    => "indices-delete-mapping",
-        method => "DELETE",
-        parts  => {
-            index => { multi => 1, required => 1 },
-            type  => { multi => 1, required => 1 },
-        },
-        paths => [
-            [ { index => 0, type => 2 }, "{index}", "_mapping", "{type}" ]
-        ],
-        qs => { filter_path => "list", master_timeout => "time" },
-    },
-
     'indices.delete_template' => {
         doc    => "indices-templates",
         method => "DELETE",
@@ -1337,17 +1424,37 @@ sub api {
     'indices.flush_synced' => {
         doc    => "indices-synced-flush",
         method => "POST",
-        parts  => {
-            allow_no_indices   => {},
-            expand_wildcards   => {},
-            ignore_unavailable => {},
-            index              => { multi => 1 },
-        },
-        paths => [
+        parts  => { index => { multi => 1 } },
+        paths  => [
             [ { index => 0 }, "{index}", "_flush", "synced" ],
             [ {}, "_flush", "synced" ],
         ],
-        qs => { filter_path => "list" },
+        qs => {
+            allow_no_indices   => "boolean",
+            expand_wildcards   => "enum",
+            filter_path        => "list",
+            ignore_unavailable => "boolean",
+        },
+    },
+
+    'indices.forcemerge' => {
+        doc    => "indices-forcemerge",
+        method => "POST",
+        parts  => { index => { multi => 1 } },
+        paths  => [
+            [ { index => 0 }, "{index}", "_forcemerge" ],
+            [ {}, "_forcemerge" ],
+        ],
+        qs => {
+            allow_no_indices     => "boolean",
+            expand_wildcards     => "enum",
+            filter_path          => "list",
+            flush                => "boolean",
+            ignore_unavailable   => "boolean",
+            max_num_segments     => "number",
+            only_expunge_deletes => "boolean",
+            wait_for_merge       => "boolean",
+        },
     },
 
     'indices.get' => {
@@ -1364,6 +1471,8 @@ sub api {
             allow_no_indices   => "boolean",
             expand_wildcards   => "enum",
             filter_path        => "list",
+            flat_settings      => "boolean",
+            human              => "boolean",
             ignore_unavailable => "boolean",
             local              => "boolean",
         },
@@ -1403,24 +1512,24 @@ sub api {
     'indices.get_field_mapping' => {
         doc   => "indices-get-field-mapping",
         parts => {
-            field => { multi => 1, required => 1 },
-            index => { multi => 1 },
-            type  => { multi => 1 },
+            fields => { multi => 1, required => 1 },
+            index  => { multi => 1 },
+            type   => { multi => 1 },
         },
         paths => [
-            [   { field => 4, index => 0, type => 2 }, "{index}",
+            [   { fields => 4, index => 0, type => 2 }, "{index}",
                 "_mapping", "{type}",
-                "field",    "{field}",
+                "field",    "{fields}",
             ],
-            [   { field => 3, index => 0 }, "{index}",
+            [   { fields => 3, index => 0 }, "{index}",
                 "_mapping", "field",
-                "{field}",
+                "{fields}",
             ],
-            [   { field => 3, type => 1 }, "_mapping",
+            [   { fields => 3, type => 1 }, "_mapping",
                 "{type}", "field",
-                "{field}",
+                "{fields}",
             ],
-            [ { field => 2 }, "_mapping", "field", "{field}" ],
+            [ { fields => 2 }, "_mapping", "field", "{fields}" ],
         ],
         qs => {
             allow_no_indices   => "boolean",
@@ -1464,6 +1573,7 @@ sub api {
             expand_wildcards   => "enum",
             filter_path        => "list",
             flat_settings      => "boolean",
+            human              => "boolean",
             ignore_unavailable => "boolean",
             local              => "boolean",
         },
@@ -1471,7 +1581,7 @@ sub api {
 
     'indices.get_template' => {
         doc   => "indices-templates",
-        parts => { name => {} },
+        parts => { name => { multi => 1 } },
         paths =>
             [ [ { name => 1 }, "_template", "{name}" ], [ {}, "_template" ] ],
         qs => {
@@ -1524,7 +1634,7 @@ sub api {
     'indices.open' => {
         doc    => "indices-open-close",
         method => "POST",
-        parts  => { index => { required => 1 } },
+        parts  => { index => { multi => 1, required => 1 } },
         paths  => [ [ { index => 0 }, "{index}", "_open" ] ],
         qs     => {
             allow_no_indices   => "boolean",
@@ -1549,7 +1659,6 @@ sub api {
             expand_wildcards     => "enum",
             filter_path          => "list",
             flush                => "boolean",
-            force                => "boolean",
             ignore_unavailable   => "boolean",
             max_num_segments     => "number",
             only_expunge_deletes => "boolean",
@@ -1587,10 +1696,10 @@ sub api {
             allow_no_indices   => "boolean",
             expand_wildcards   => "enum",
             filter_path        => "list",
-            ignore_conflicts   => "boolean",
             ignore_unavailable => "boolean",
             master_timeout     => "time",
             timeout            => "time",
+            update_all_types   => "boolean",
         },
     },
 
@@ -1651,6 +1760,7 @@ sub api {
             filter_path        => "list",
             ignore_unavailable => "boolean",
             master_timeout     => "time",
+            request_cache      => "boolean",
         },
     },
 
@@ -1697,6 +1807,23 @@ sub api {
             filter_path        => "list",
             human              => "boolean",
             ignore_unavailable => "boolean",
+            verbose            => "boolean",
+        },
+    },
+
+    'indices.shard_stores' => {
+        doc   => "indices-shards-stores",
+        parts => { index => { multi => 1 } },
+        paths => [
+            [ { index => 0 }, "{index}", "_shard_stores" ],
+            [ {}, "_shard_stores" ],
+        ],
+        qs => {
+            allow_no_indices   => "boolean",
+            expand_wildcards   => "enum",
+            filter_path        => "list",
+            ignore_unavailable => "boolean",
+            status             => "list",
         },
     },
 
@@ -1721,22 +1848,6 @@ sub api {
         },
     },
 
-    'indices.status' => {
-        doc   => "indices-status",
-        parts => { index => { multi => 1 } },
-        paths =>
-            [ [ { index => 0 }, "{index}", "_status" ], [ {}, "_status" ] ],
-        qs => {
-            allow_no_indices   => "boolean",
-            expand_wildcards   => "enum",
-            filter_path        => "list",
-            human              => "boolean",
-            ignore_unavailable => "boolean",
-            recovery           => "boolean",
-            snapshot           => "boolean",
-        },
-    },
-
     'indices.update_aliases' => {
         body   => { required => 1 },
         doc    => "indices-aliases",
@@ -1832,20 +1943,6 @@ sub api {
         },
     },
 
-    'nodes.shutdown' => {
-        doc    => "cluster-nodes-shutdown",
-        method => "POST",
-        parts  => { node_id => { multi => 1 } },
-        paths  => [
-            [   { node_id => 2 }, "_cluster",
-                "nodes", "{node_id}",
-                "_shutdown"
-            ],
-            [ {}, "_shutdown" ],
-        ],
-        qs => { delay => "time", exit => "boolean", filter_path => "list" },
-    },
-
     'nodes.stats' => {
         doc   => "cluster-nodes-stats",
         parts => {
@@ -2020,6 +2117,39 @@ sub api {
         },
     },
 
+    'tasks.cancel' => {
+        doc    => "tasks-cancel",
+        method => "POST",
+        parts  => { task_id => {} },
+        paths  => [
+            [ { task_id => 1 }, "_tasks", "{task_id}", "_cancel" ],
+            [ {}, "_tasks", "_cancel" ],
+        ],
+        qs => {
+            actions     => "list",
+            filter_path => "list",
+            node_id     => "list",
+            parent_node => "string",
+            parent_task => "string",
+        },
+    },
+
+    'tasks.list' => {
+        doc   => "tasks-list",
+        parts => { task_id => {} },
+        paths =>
+            [ [ { task_id => 1 }, "_tasks", "{task_id}" ], [ {}, "_tasks" ] ],
+        qs => {
+            actions             => "list",
+            detailed            => "boolean",
+            filter_path         => "list",
+            node_id             => "list",
+            parent_node         => "string",
+            parent_task         => "string",
+            wait_for_completion => "boolean",
+        },
+    },
+
 #=== AUTOGEN - END ===
 
 );
@@ -2033,16 +2163,16 @@ __PACKAGE__->_qs_init( \%API );
 
 =head1 NAME
 
-Search::Elasticsearch::Client::1_0::Role::API - This class contains the spec for the Elasticsearch APIs
+Search::Elasticsearch::Client::2_0::Role::API - This class contains the spec for the Elasticsearch APIs
 
 =head1 VERSION
 
-version 7.30_1
+version 5.00
 
 =head1 DESCRIPTION
 
 All of the Elasticsearch APIs are defined in this role. The example given below
-is the definition for the L<Search::Elasticsearch::Client::1_0::Direct/index()> method:
+is the definition for the L<Search::Elasticsearch::Client::2_0::Direct/index()> method:
 
     'index' => {
         body   => { required => 1 },
@@ -2060,18 +2190,17 @@ is the definition for the L<Search::Elasticsearch::Client::1_0::Direct/index()>
             [ { index => 0, type => 1 }, "{index}", "{type}" ],
         ],
         qs => {
-            filter_path            => "list",
-            op_type                => "enum",
-            parent                 => "string",
-            pipeline               => "string",
-            refresh                => "enum",
-            routing                => "string",
-            timeout                => "time",
-            timestamp              => "time",
-            ttl                    => "time",
-            version                => "number",
-            version_type           => "enum",
-            wait_for_active_shards => "string",
+            consistency  => "enum",
+            filter_path  => "list",
+            op_type      => "enum",
+            parent       => "string",
+            refresh      => "boolean",
+            routing      => "string",
+            timeout      => "time",
+            timestamp    => "time",
+            ttl          => "time",
+            version      => "number",
+            version_type => "enum",
         },
     },
 
@@ -2101,17 +2230,17 @@ L<Search::Elasticsearch::Role::API>
 
 =item *
 
-L<Search::Elasticsearch::Client::1_0::Direct>
+L<Search::Elasticsearch::Client::2_0::Direct>
 
 =back
 
 =head1 AUTHOR
 
-Enrico Zimuel <enrico.zimuel@elastic.co>
+Clinton Gormley <drtech@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2020 by Elasticsearch BV.
+This software is Copyright (c) 2016 by Elasticsearch BV.
 
 This is free software, licensed under:
 
