@@ -1,11 +1,5 @@
-# Licensed to Elasticsearch B.V under one or more agreements.
-# Elasticsearch B.V licenses this file to you under the Apache 2.0 License.
-# See the LICENSE file in the project root for more information
-
-package Search::Elasticsearch::Client::1_0::Role::Bulk;
-$Search::Elasticsearch::Client::1_0::Role::Bulk::VERSION = '7.30_1'; # TRIAL
-
-$Search::Elasticsearch::Client::1_0::Role::Bulk::VERSION = '7.301';
+package Search::Elasticsearch::Client::2_0::Role::Bulk;
+$Search::Elasticsearch::Client::2_0::Role::Bulk::VERSION = '5.00';
 use Moo::Role;
 requires 'add_action', 'flush';
 
@@ -278,7 +272,7 @@ sub _doc_transformer {
 
 1;
 
-# ABSTRACT: Provides common functionality to L<Elasticseach::Client::1_0::Bulk> and L<Search::Elasticsearch::Client::1_0::Async::Bulk>
+# ABSTRACT: Provides common functionality to L<Elasticseach::Client::2_0::Bulk> and L<Search::Elasticsearch::Client::2_0::Async::Bulk>
 
 __END__
 
@@ -288,19 +282,19 @@ __END__
 
 =head1 NAME
 
-Search::Elasticsearch::Client::1_0::Role::Bulk - Provides common functionality to L<Elasticseach::Client::1_0::Bulk> and L<Search::Elasticsearch::Client::1_0::Async::Bulk>
+Search::Elasticsearch::Client::2_0::Role::Bulk - Provides common functionality to L<Elasticseach::Client::2_0::Bulk> and L<Search::Elasticsearch::Client::2_0::Async::Bulk>
 
 =head1 VERSION
 
-version 7.30_1
+version 5.00
 
 =head1 AUTHOR
 
-Enrico Zimuel <enrico.zimuel@elastic.co>
+Clinton Gormley <drtech@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2020 by Elasticsearch BV.
+This software is Copyright (c) 2016 by Elasticsearch BV.
 
 This is free software, licensed under:
 
