@@ -1,11 +1,5 @@
-# Licensed to Elasticsearch B.V under one or more agreements.
-# Elasticsearch B.V licenses this file to you under the Apache 2.0 License.
-# See the LICENSE file in the project root for more information
-
-package Search::Elasticsearch::Client::1_0::Role::Scroll;
-$Search::Elasticsearch::Client::1_0::Role::Scroll::VERSION = '7.30_1'; # TRIAL
-
-$Search::Elasticsearch::Client::1_0::Role::Scroll::VERSION = '7.301';
+package Search::Elasticsearch::Client::2_0::Role::Scroll;
+$Search::Elasticsearch::Client::2_0::Role::Scroll::VERSION = '5.00';
 use Moo::Role;
 requires 'finish';
 use Search::Elasticsearch::Util qw(parse_params throw);
@@ -56,7 +50,7 @@ sub DEMOLISH {
 
 1;
 
-# ABSTRACT: Provides common functionality to L<Search::Elasticsearch::Client::1_0::Scroll> and L<Search::Elasticsearch::Client::1_0::Async::Scroll>
+# ABSTRACT: Provides common functionality to L<Search::Elasticsearch::Client::2_0::Scroll> and L<Search::Elasticsearch::Client::2_0::Async::Scroll>
 
 __END__
 
@@ -66,19 +60,19 @@ __END__
 
 =head1 NAME
 
-Search::Elasticsearch::Client::1_0::Role::Scroll - Provides common functionality to L<Search::Elasticsearch::Client::1_0::Scroll> and L<Search::Elasticsearch::Client::1_0::Async::Scroll>
+Search::Elasticsearch::Client::2_0::Role::Scroll - Provides common functionality to L<Search::Elasticsearch::Client::2_0::Scroll> and L<Search::Elasticsearch::Client::2_0::Async::Scroll>
 
 =head1 VERSION
 
-version 7.30_1
+version 5.00
 
 =head1 AUTHOR
 
-Enrico Zimuel <enrico.zimuel@elastic.co>
+Clinton Gormley <drtech@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2020 by Elasticsearch BV.
+This software is Copyright (c) 2016 by Elasticsearch BV.
 
 This is free software, licensed under:
 
